Widgets
=======

Each documentation file comprehensively explains the widget and
how it is ensured to work properly.

.. toctree::
   :maxdepth: 1

   checkbox
   radio
   text
   textarea
   textlines
   password
   select-index
   orderedselect
   file
   file-testing
   image
   multi-index
   object-index
   button
   submit
